@@ -1,14 +1,15 @@
-module RawFilePath.Import
-    ( module Module
-    , ByteString
-    , RawFilePath
-    ) where
+module RawFilePath.Import (
+  module Module,
+  ByteString,
+  RawFilePath,
+) where
 
 import Control.Applicative as Module
 import Control.Concurrent as Module
 import Control.Exception as Module
 import Control.Monad as Module
 import Data.Bits as Module
+import Data.ByteString (ByteString)
 import Data.Char as Module
 import Data.Functor as Module
 import Data.Maybe as Module
@@ -17,7 +18,7 @@ import Data.Typeable as Module
 import Data.Word as Module
 import Foreign as Module hiding (void)
 import Foreign.C as Module
-import GHC.IO.Device as Module hiding (close, getEcho, setEcho, Directory)
+import GHC.IO.Device as Module hiding (Directory, close, getEcho, setEcho)
 import GHC.IO.Encoding as Module
 import GHC.IO.Exception as Module
 import GHC.IO.Handle.Internals as Module
@@ -27,7 +28,5 @@ import System.Exit as Module
 import System.IO as Module
 import System.IO.Error as Module
 import System.IO.Unsafe as Module
-
-import Data.ByteString (ByteString)
-import System.Posix.Types as Module
 import System.Posix.ByteString (RawFilePath)
+import System.Posix.Types as Module
